Method: Sentry::Mechanism#handled

Defined in:
lib/sentry/interfaces/mechanism.rb

#handledBoolean

A manually captured exception has handled set to true, false if coming from an integration where we intercept an uncaught exception. Defaults to true here and will be set to false explicitly in integrations.

Returns:

  • (Boolean)


13
14
15
# File 'lib/sentry/interfaces/mechanism.rb', line 13

def handled
  @handled
end