Method: Sentry::Configuration#background_worker_threads
- Defined in:
- lib/sentry/configuration.rb
#background_worker_threads ⇒ Object
to send events in a non-blocking way, sentry-ruby has its own background worker by default, the worker holds a thread pool that has [the number of processors] threads but you can configure it with this configuration option E.g.: config.background_worker_threads = 5
if you want to send events synchronously, set the value to 0 E.g.: config.background_worker_threads = 0
26 27 28 |
# File 'lib/sentry/configuration.rb', line 26 def background_worker_threads @background_worker_threads end |