Method: Sentry::Transport::Configuration#proxy
- Defined in:
- lib/sentry/transport/configuration.rb
#proxy ⇒ String, ...
The proxy configuration to use to connect to Sentry. Accepts either a URI formatted string, URI, or a hash with the uri, user, and password keys.
If you’re using the default transport (Sentry::HTTPTransport), proxy settings will also automatically be read from tne environment variables (HTTP_PROXY, HTTPS_PROXY, NO_PROXY).
41 42 43 |
# File 'lib/sentry/transport/configuration.rb', line 41 def proxy @proxy end |